#include <SoftwareSerial.h>
#include <Adafruit_NeoPixel.h>
extern "C" {
#include "user_interface.h"
}
#define PIXEL_PIN   D5    // Digital IO pin connected to the NeoPixels.
#define PIXEL_COUNT 1
EspClass esp;
int CO2Wert;              // CO2 Messwert in ppm
uint32_t farbe = 0;
int Messinterval = 1;     // 1 Minute

SoftwareSerial co2Serial(D2, D1); // RX, TX Pinns festlegen
Adafruit_NeoPixel strip = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, NEO_GRB + NEO_KHZ800);

int leseCO2()                         // Kommunikation mit MH-Z19 CO2 Sensor
{
  byte cmd[9] = {0xFF, 0x01, 0x86, 0x00, 0x00, 0x00, 0x00, 0x00, 0x79};
  char antwort[9];
  co2Serial.write(cmd, 9);
  co2Serial.readBytes(antwort, 9);
  if (antwort[0] != 0xFF) return -1;
  if (antwort[1] != 0x86) return -1;
  int antwortHigh = (int) antwort[2]; // CO2 High Byte
  int antwortLow = (int) antwort[3];  // CO2 Low Byte
  int ppm = (256 * antwortHigh) + antwortLow;
  return ppm;                         // Antwort des MH-Z19 CO2 Sensors in ppm
}

void setup()
{            
  co2Serial.begin(9600);
  CO2Wert = leseCO2();                // MH-Z19 CO2 Sensor lesen

  int temp = 150 - (150 * CO2Wert / 1800);  // CO2 in Farbe Umrechnen
  if (temp < 0)temp += 256;
  uint ADCValue = 0;                    
  ADCValue = system_adc_read();             // LDR Wert lesen
  int x = ADCValue / 5;
  if (x < 0)x = 0;
  if (x > 100)x = 100;                      
  farbe = Wheel(temp, x, x, x);             // Farbe und Intensität einstellen
  strip.begin();                            // WS2812B RGB initialisieren 
  strip.setPixelColor(0, farbe);            
  strip.show();                             // Daten zum WS2812B RGB LED senden
  Serial.begin(115200);
  Serial.println("");
  Serial.println("Start");
  esp.deepSleep(Messinterval * 60e6, WAKE_RF_DISABLED); // ESP8266 geht für x Minuten schlafen
}

void loop()
{
  yield();
}

// Input a value 0 to 255 to get a color value.
// The colours are a transition r - g - b - back to r.
uint32_t Wheel(byte Wert, byte Rdimm, byte Gdimm, byte Bdimm)
{
  uint16_t Phase, Blue, Green, Red, Level;
  Phase = Wert / 42;
  Level = Wert % 42;

  switch ( Phase )
  {
    case 0:                 //
      {
        Red   = 255;
        Green = Level * 6;
        Blue  = 0;
      }
      break;

    case 1:
      {
        Red   = 255 - Level * 6;
        Green = 255;
        Blue  = 0;
      }
      break;

    case 2:
      {
        Red   = 0;
        Green = 255;
        Blue  = Level * 6;
      }
      break;

    case 3:
      {
        Red   = 0;
        Green = 255 - Level * 6;
        Blue  = 255;
      }
      break;

    case 4:
      {
        Red   = Level * 6;
        Green = 0;
        Blue  = 255;
      }
      break;
    case 5:
      {
        Red   = 255;
        Green = 0;
        Blue  = 255 - Level * 6;
      }
      break;

    default:
      Red = Green = Blue = 255;
  }
  return strip.Color(Red * Rdimm / 100, Green * Gdimm / 100, Blue * Bdimm / 100);
}
